/*
* file CcResource.java
*
* Licensed Materials - Property of IBM
* Restricted Materials of IBM
* 
* com.ibm.rational.wvcm.stp.cc.CcResource
*
* (C) Copyright IBM Corporation 2004, 2011.  All Rights Reserved. 
* Note to U.S. Government Users Restricted Rights:  Use, duplication or  
* disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
*/


package com.ibm.rational.wvcm.stp.cc;

import javax.wvcm.PropertyRequestItem;
import javax.wvcm.WvcmException;

import com.ibm.rational.wvcm.stp.StpResource;

/**
 * <p>A proxy for a resource in a ClearCase VOB or view.
 * </p>
 */
public interface CcResource extends StpResource {

    /**
     * Construct a new proxy for this resource. 
     * This new proxy will be of the most correct, most derived class for this
     * resource, based on currently available information in the resource's
     * location, on the local client machine, and/or on the ClearCase server.
     * In addition, this new proxy will have its identity
     * correctly set so that its equals() and hashMap() methods will work
     * correctly.
     * <p>Unresolved resource proxies should not be used in situations where
     * equality matters, especially in maps, lists, sets, and other collection
     * classes.
     * </p>
     * @return a new proxy of the correct, most specific resource type
     */
    public CcResource doResolve() throws WvcmException;

    /**
     * Has this proxy already been resolved?
     * @return true if this proxy has been resolved; else false
     * @see #doResolve()
     */
    public boolean isResolved() throws WvcmException;
    
    /**
     * Get the ClearCase provider associated with this resource proxy.
     * This is normally the network provider for the CCRC WAN server on which
     * this remote resource resides, or a local provider if this is a local
     * ClearCase resource.
     */
    CcProvider ccProvider();

    /**
     * Checks if this proxy contains valid values for the provided properties, if
     * and only if, they are supported.  Properties which are unsupported by the 
     * server are ignored.
     * 
     * @param wantedProp A PropertyRequestItem, possibly with multiple nested
     *            properties, to check the value for. Cannot be
     *            <code>null</code>.
     * 
     * @return <code>true</code> if there is an entry in this proxy for all
     *         server supported properties of the PropertyRequestItem, 
     *         and those entries contain a valid value; <code>false</code> otherwise.
     */
    public boolean hasSupportedProperties(PropertyRequestItem wantedProp);
}
